@@ -1,5 +1,6 @@
 """Base Class for Strategies"""
 from datetime import datetime
+from enum import Enum
 from typing import Dict, List, Tuple
 
 import alpaca_trade_api as tradeapi
@@ -9,15 +10,22 @@ from liualgotrader.common import config
 from liualgotrader.models.algo_run import AlgoRun
 
 
+class StrategyType(Enum):
+    DAY_TRADE = 1
+    SWING = 2
+
+
 class Strategy:
     def __init__(
         self,
         name: str,
+        type: StrategyType,
         batch_id: str,
         schedule: List[Dict],
         ref_run_id: int = None,
     ):
         self.name = name
+        self.type = type
         self.ref_run_id = ref_run_id
         self.algo_run = AlgoRun(strategy_name=self.name, batch_id=batch_id)
         self.schedule = schedule
@@ -49,7 +57,10 @@ class Strategy:
                     >= schedule["start"]
                     for schedule in self.schedule
                 )
-                or config.bypass_market_schedule
+                or (
+                    hasattr(config, "bypass_market_schedule")
+                    and config.bypass_market_schedule
+                )
             )
             and (config.market_close - now).seconds // 60 > 15
             else False
@@ -64,7 +75,10 @@ class Strategy:
                 > schedule["start"]
                 for schedule in self.schedule
             )
-            or config.bypass_market_schedule
+            or (
+                hasattr(config, "bypass_market_schedule")
+                and config.bypass_market_schedule
+            )
             else False
         )
 
